#
# PySNMP MIB module MBG-SYNCBOX-N2X-MIB (https://www.pysnmp.com/pysmi)
# ASN.1 source file://./MBG-SYNCBOX-N2X-MIB.mib
# Produced by pysmi-1.1.13 at Fri Oct 27 11:50:07 2023
# On host HAWKING platform Linux version 5.15.90.1-microsoft-standard-WSL2 by user davidvng
# Using Python version 3.8.8 (default, Apr 13 2021, 19:58:26)
#

Integer, ObjectIdentifier, OctetString = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
NamedValues, = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
ValueSizeConstraint, ConstraintsIntersection, ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion")
mbgSnmpRoot, = mibBuilder.importSymbols("MBG-SNMP-ROOT-MIB", "mbgSnmpRoot")
NotificationGroup, ModuleCompliance, ObjectGroup = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
NotificationType, Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, TimeTicks, ObjectIdentity, iso, ModuleIdentity, Counter64, Unsigned32, Bits, Gauge32, Counter32, IpAddress, MibIdentifier = mibBuilder.importSymbols("SNMPv2-SMI", "NotificationType", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "TimeTicks", "ObjectIdentity", "iso", "ModuleIdentity", "Counter64", "Unsigned32", "Bits", "Gauge32", "Counter32", "IpAddress", "MibIdentifier")
TextualConvention, DisplayString = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
mbgSyncboxN2X = ModuleIdentity((1, 3, 6, 1, 4, 1, 5597, 40))
mbgSyncboxN2X.setRevisions(('2013-09-03 00:00',))
if mibBuilder.loadTexts:
    mbgSyncboxN2X.setLastUpdated('201309030000Z')
if mibBuilder.loadTexts:
    mbgSyncboxN2X.setOrganization('www.meinberg.de')
mbgSyncboxN2XGeneral = MibIdentifier((1, 3, 6, 1, 4, 1, 5597, 40, 0))
mbgSyncboxN2XSerialNumber = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 0, 1), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XSerialNumber.setStatus('current')
mbgSyncboxN2XFirmwareRevision = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 0, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XFirmwareRevision.setStatus('current')
mbgSyncboxN2XSystemTime = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 0, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XSystemTime.setStatus('current')
mbgSyncboxN2XCurrentRefSource = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 0, 4), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XCurrentRefSource.setStatus('current')
mbgSyncboxN2XNetworkTimeProtocol = MibIdentifier((1, 3, 6, 1, 4, 1, 5597, 40, 1))
mbgSyncboxN2XNtpSyncStatus = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 1, 1), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpSyncStatus.setStatus('current')
mbgSyncboxN2XNtpSystemPeer = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpSystemPeer.setStatus('current')
mbgSyncboxN2XNtpStratum = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 1, 3), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpStratum.setStatus('current')
mbgSyncboxN2XNtpRefSourceTable = MibTable((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4), )
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceTable.setStatus('current')
mbgSyncboxN2XNtpRefSourceTableEntry = MibTableRow((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1), ).setIndexNames((0, "MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceIndex"))
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceTableEntry.setStatus('current')
mbgSyncboxN2XNtpRefSourceIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0, 6)))
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceIndex.setStatus('current')
mbgSyncboxN2XNtpRefSourceHostname = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceHostname.setStatus('current')
mbgSyncboxN2XNtpRefSourceStratum = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 3), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceStratum.setStatus('current')
mbgSyncboxN2XNtpRefSourceReferenceID = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 4), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceReferenceID.setStatus('current')
mbgSyncboxN2XNtpRefSourceReach = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 5), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceReach.setStatus('current')
mbgSyncboxN2XNtpRefSourceCurrPoll = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 6), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceCurrPoll.setStatus('current')
mbgSyncboxN2XNtpRefSourceMinPoll = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 7), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceMinPoll.setStatus('current')
mbgSyncboxN2XNtpRefSourceMaxPoll = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 8), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceMaxPoll.setStatus('current')
mbgSyncboxN2XNtpRefSourceConfigOptions = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 9), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceConfigOptions.setStatus('current')
mbgSyncboxN2XNtpRefSourcePathDelay = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 10), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourcePathDelay.setStatus('current')
mbgSyncboxN2XNtpRefSourceOffset = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 11), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceOffset.setStatus('current')
mbgSyncboxN2XNtpRefSourceJitter = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 1, 4, 1, 12), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XNtpRefSourceJitter.setStatus('current')
mbgSyncboxN2XPrecisionTimeProtocol = MibIdentifier((1, 3, 6, 1, 4, 1, 5597, 40, 2))
mbgSyncboxN2XPtpProfile = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2))).clone(namedValues=NamedValues(("none", 0), ("power", 1), ("telecom", 2)))).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpProfile.setStatus('current')
mbgSyncboxN2XPtpNwProt = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5, 6))).clone(namedValues=NamedValues(("unknown", 0), ("ipv4", 1), ("ipv6", 2), ("ieee802-3", 3), ("deviceNet", 4), ("controlNet", 5), ("profiNet", 6)))).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpNwProt.setStatus('current')
mbgSyncboxN2XPtpPortState = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5, 6, 7, 8, 9))).clone(namedValues=NamedValues(("uninitialized", 0), ("initializing", 1), ("faulty", 2), ("disabled", 3), ("listening", 4), ("preMaster", 5), ("master", 6), ("passive", 7), ("uncalibrated", 8), ("slave", 9)))).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpPortState.setStatus('current')
mbgSyncboxN2XPtpDelayMechanism = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1))).clone(namedValues=NamedValues(("e2e", 0), ("p2p", 1)))).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpDelayMechanism.setStatus('current')
mbgSyncboxN2XPtpDelayRequestInterval = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 5), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpDelayRequestInterval.setStatus('current')
mbgSyncboxN2XPtpTimescale = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1))).clone(namedValues=NamedValues(("tai", 0), ("arb", 1)))).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpTimescale.setStatus('current')
mbgSyncboxN2XPtpUTCOffset = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 7), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpUTCOffset.setStatus('current')
mbgSyncboxN2XPtpLeapSecondAnnounced = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 8), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpLeapSecondAnnounced.setStatus('current')
mbgSyncboxN2XPtpGrandmasterClockID = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 9), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpGrandmasterClockID.setStatus('current')
mbgSyncboxN2XPtpGrandmasterTimesource = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(16, 32, 48, 64, 80, 96, 144, 160))).clone(namedValues=NamedValues(("atomicClock", 16), ("gps", 32), ("terrestrialRadio", 48), ("ptp", 64), ("ntp", 80), ("handSet", 96), ("other", 144), ("internalOscillator", 160)))).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpGrandmasterTimesource.setStatus('current')
mbgSyncboxN2XPtpGrandmasterPriority1 = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 11), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpGrandmasterPriority1.setStatus('current')
mbgSyncboxN2XPtpGrandmasterClockClass = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 12), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpGrandmasterClockClass.setStatus('current')
mbgSyncboxN2XPtpGrandmasterClockAccuracy = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49))).clone(namedValues=NamedValues(("accurateToWithin25ns", 32), ("accurateToWithin100ns", 33), ("accurateToWithin250ns", 34), ("accurateToWithin1us", 35), ("accurateToWithin2Point5us", 36), ("accurateToWithin10us", 37), ("accurateToWithin25us", 38), ("accurateToWithin100us", 39), ("accurateToWithin250us", 40), ("accurateToWithin1ms", 41), ("accurateToWithin2Point5ms", 42), ("accurateToWithin10ms", 43), ("accurateToWithin25ms", 44), ("accurateToWithin100ms", 45), ("accurateToWithin250ms", 46), ("accurateToWithin1s", 47), ("accurateToWithin10s", 48), ("accurateToGreaterThan10s", 49)))).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpGrandmasterClockAccuracy.setStatus('current')
mbgSyncboxN2XPtpGrandmasterClockVariance = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 14), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpGrandmasterClockVariance.setStatus('current')
mbgSyncboxN2XPtpGrandmasterPriority2 = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 15), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpGrandmasterPriority2.setStatus('current')
mbgSyncboxN2XPtpOffsetToGrandmaster = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 16), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpOffsetToGrandmaster.setStatus('current')
mbgSyncboxN2XPtpMeanPathDelay = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 2, 17), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XPtpMeanPathDelay.setStatus('current')
mbgSyncboxN2XOutputs = MibIdentifier((1, 3, 6, 1, 4, 1, 5597, 40, 3))
mbgSyncboxN2XOutputsTable = MibTable((1, 3, 6, 1, 4, 1, 5597, 40, 3, 1), )
if mibBuilder.loadTexts:
    mbgSyncboxN2XOutputsTable.setStatus('current')
mbgSyncboxN2XOutputsTableEntry = MibTableRow((1, 3, 6, 1, 4, 1, 5597, 40, 3, 1, 1), ).setIndexNames((0, "MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XOutputIndex"))
if mibBuilder.loadTexts:
    mbgSyncboxN2XOutputsTableEntry.setStatus('current')
mbgSyncboxN2XOutputIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 3, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0, 2)))
if mibBuilder.loadTexts:
    mbgSyncboxN2XOutputIndex.setStatus('current')
mbgSyncboxN2XOutputMode = MibTableColumn((1, 3, 6, 1, 4, 1, 5597, 40, 3, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16))).clone(namedValues=NamedValues(("idle", 0), ("timer", 1), ("singleShot", 2), ("cyclicPulse", 3), ("pulsePerSecond", 4), ("pulsePerMinute", 5), ("pulsePerHour", 6), ("emulatedDCF77", 7), ("positionOK", 8), ("timeSync", 9), ("allSync", 10), ("timecode", 11), ("timestring", 12), ("tenMHz", 13), ("emulatedDCF77M59", 14), ("synthesizer", 15), ("timeSlots", 16)))).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XOutputMode.setStatus('current')
mbgSyncboxN2XSerialString = MibScalar((1, 3, 6, 1, 4, 1, 5597, 40, 3, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts:
    mbgSyncboxN2XSerialString.setStatus('current')
mbgSyncboxN2XConformance = MibIdentifier((1, 3, 6, 1, 4, 1, 5597, 40, 10))
mbgSyncboxN2XCompliances = MibIdentifier((1, 3, 6, 1, 4, 1, 5597, 40, 10, 0))
mbgSyncboxN2XGroups = MibIdentifier((1, 3, 6, 1, 4, 1, 5597, 40, 10, 1))
mbgSyncboxN2XCompliance = ModuleCompliance((1, 3, 6, 1, 4, 1, 5597, 40, 10, 0, 0)).setObjects(("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XObjectsGroup"))

if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    mbgSyncboxN2XCompliance = mbgSyncboxN2XCompliance.setStatus('current')
mbgSyncboxN2XObjectsGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 5597, 40, 10, 1, 0)).setObjects(("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XSerialNumber"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XFirmwareRevision"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XSystemTime"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XCurrentRefSource"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpSyncStatus"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpSystemPeer"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpStratum"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceHostname"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceStratum"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceReferenceID"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceReach"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceCurrPoll"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceMinPoll"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceMaxPoll"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceConfigOptions"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourcePathDelay"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceOffset"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XNtpRefSourceJitter"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpProfile"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpNwProt"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpPortState"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpDelayMechanism"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpDelayRequestInterval"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpTimescale"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpUTCOffset"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpLeapSecondAnnounced"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpGrandmasterClockID"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpGrandmasterTimesource"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpGrandmasterPriority1"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpGrandmasterClockClass"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpGrandmasterClockAccuracy"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpGrandmasterClockVariance"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpGrandmasterPriority2"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpOffsetToGrandmaster"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XPtpMeanPathDelay"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XOutputMode"), ("MBG-SYNCBOX-N2X-MIB", "mbgSyncboxN2XSerialString"))
if getattr(mibBuilder, 'version', (0, 0, 0)) > (4, 4, 0):
    mbgSyncboxN2XObjectsGroup = mbgSyncboxN2XObjectsGroup.setStatus('current')
mibBuilder.exportSymbols("MBG-SYNCBOX-N2X-MIB", mbgSyncboxN2XPtpPortState=mbgSyncboxN2XPtpPortState, mbgSyncboxN2XPtpGrandmasterClockAccuracy=mbgSyncboxN2XPtpGrandmasterClockAccuracy, mbgSyncboxN2XCompliances=mbgSyncboxN2XCompliances, mbgSyncboxN2XNtpSyncStatus=mbgSyncboxN2XNtpSyncStatus, mbgSyncboxN2XNtpRefSourceTable=mbgSyncboxN2XNtpRefSourceTable, mbgSyncboxN2XPtpGrandmasterClockVariance=mbgSyncboxN2XPtpGrandmasterClockVariance, mbgSyncboxN2XNtpRefSourceCurrPoll=mbgSyncboxN2XNtpRefSourceCurrPoll, mbgSyncboxN2XNtpRefSourceReach=mbgSyncboxN2XNtpRefSourceReach, mbgSyncboxN2XNtpRefSourceJitter=mbgSyncboxN2XNtpRefSourceJitter, mbgSyncboxN2XSerialString=mbgSyncboxN2XSerialString, mbgSyncboxN2XNtpRefSourceMinPoll=mbgSyncboxN2XNtpRefSourceMinPoll, PYSNMP_MODULE_ID=mbgSyncboxN2X, mbgSyncboxN2XNtpRefSourceReferenceID=mbgSyncboxN2XNtpRefSourceReferenceID, mbgSyncboxN2XNtpRefSourceTableEntry=mbgSyncboxN2XNtpRefSourceTableEntry, mbgSyncboxN2XPtpOffsetToGrandmaster=mbgSyncboxN2XPtpOffsetToGrandmaster, mbgSyncboxN2XSystemTime=mbgSyncboxN2XSystemTime, mbgSyncboxN2XNtpRefSourceStratum=mbgSyncboxN2XNtpRefSourceStratum, mbgSyncboxN2XOutputsTableEntry=mbgSyncboxN2XOutputsTableEntry, mbgSyncboxN2XOutputMode=mbgSyncboxN2XOutputMode, mbgSyncboxN2XOutputIndex=mbgSyncboxN2XOutputIndex, mbgSyncboxN2XObjectsGroup=mbgSyncboxN2XObjectsGroup, mbgSyncboxN2XNtpRefSourceIndex=mbgSyncboxN2XNtpRefSourceIndex, mbgSyncboxN2XFirmwareRevision=mbgSyncboxN2XFirmwareRevision, mbgSyncboxN2XPtpGrandmasterPriority2=mbgSyncboxN2XPtpGrandmasterPriority2, mbgSyncboxN2XPtpGrandmasterClockClass=mbgSyncboxN2XPtpGrandmasterClockClass, mbgSyncboxN2XNtpRefSourceHostname=mbgSyncboxN2XNtpRefSourceHostname, mbgSyncboxN2XPrecisionTimeProtocol=mbgSyncboxN2XPrecisionTimeProtocol, mbgSyncboxN2XNtpSystemPeer=mbgSyncboxN2XNtpSystemPeer, mbgSyncboxN2X=mbgSyncboxN2X, mbgSyncboxN2XPtpMeanPathDelay=mbgSyncboxN2XPtpMeanPathDelay, mbgSyncboxN2XGroups=mbgSyncboxN2XGroups, mbgSyncboxN2XConformance=mbgSyncboxN2XConformance, mbgSyncboxN2XNtpRefSourceConfigOptions=mbgSyncboxN2XNtpRefSourceConfigOptions, mbgSyncboxN2XNtpRefSourceMaxPoll=mbgSyncboxN2XNtpRefSourceMaxPoll, mbgSyncboxN2XPtpGrandmasterClockID=mbgSyncboxN2XPtpGrandmasterClockID, mbgSyncboxN2XOutputs=mbgSyncboxN2XOutputs, mbgSyncboxN2XPtpDelayRequestInterval=mbgSyncboxN2XPtpDelayRequestInterval, mbgSyncboxN2XNtpRefSourcePathDelay=mbgSyncboxN2XNtpRefSourcePathDelay, mbgSyncboxN2XGeneral=mbgSyncboxN2XGeneral, mbgSyncboxN2XNtpRefSourceOffset=mbgSyncboxN2XNtpRefSourceOffset, mbgSyncboxN2XPtpGrandmasterTimesource=mbgSyncboxN2XPtpGrandmasterTimesource, mbgSyncboxN2XPtpGrandmasterPriority1=mbgSyncboxN2XPtpGrandmasterPriority1, mbgSyncboxN2XPtpDelayMechanism=mbgSyncboxN2XPtpDelayMechanism, mbgSyncboxN2XNetworkTimeProtocol=mbgSyncboxN2XNetworkTimeProtocol, mbgSyncboxN2XSerialNumber=mbgSyncboxN2XSerialNumber, mbgSyncboxN2XCompliance=mbgSyncboxN2XCompliance, mbgSyncboxN2XOutputsTable=mbgSyncboxN2XOutputsTable, mbgSyncboxN2XPtpNwProt=mbgSyncboxN2XPtpNwProt, mbgSyncboxN2XPtpUTCOffset=mbgSyncboxN2XPtpUTCOffset, mbgSyncboxN2XNtpStratum=mbgSyncboxN2XNtpStratum, mbgSyncboxN2XPtpLeapSecondAnnounced=mbgSyncboxN2XPtpLeapSecondAnnounced, mbgSyncboxN2XPtpTimescale=mbgSyncboxN2XPtpTimescale, mbgSyncboxN2XPtpProfile=mbgSyncboxN2XPtpProfile, mbgSyncboxN2XCurrentRefSource=mbgSyncboxN2XCurrentRefSource)



from ocs.ocs_client import OCSClient


class MultiSlotController:
    """
    Simple client controller useful for managing all pysmurf-controller
    agents that exist on a network. This can dispatch operations and check
    operation status for any or all pysmurf-controllers on a network.

    Args
    -----
    client_args: list
        List of command line arguments to pass onto the OCSClient objects.

    Attributes
    ---------------
    smurfs : dict
        Dictionary containing OCSClient objects for each pysmurf-controller
        on the network. This assumes pysmurf controller agents have
        instance-id's of the form ``pysmurf-controller-<id>`` where id
        can be the uxm-id or something like ``crate1slot2``. The keys of this
        dict will be ``<id>``. This is populated from the registry agent on
        init or using the funciton ``get_active_smurfs``.

    Example
    ----------
    >>> msc = MultiSlotController()
    >>> print(msc.keys())
    dict_keys(['c1s2', 'c1s3', 'c1s4', 'c1s5', 'c1s6', 'c1s7'])
    >>> msc.start('uxm_setup')  # Run UXM Setup on all slots
    >>> # Waits for all slots to finish setup. You should monitor logs or check
    >>> # returned session-data to make sure this ran correctly
    >>> msc.wait('uxm_setup')
    >>> # Streams for 30 seconds on slots 2 and 3
    >>> msc.start('stream', ids=['c1s2', 'c1s3'], duration=30)
    >>> msc.wait('stream')  # Waits for controllers to finish streaming

    """

    def __init__(self, client_args=[]):
        self.client_args = client_args
        self.reg = OCSClient('registry', args=client_args)
        self.smurfs = {}
        self.get_active_smurfs()

    def get_active_smurfs(self):
        """
        Obtains a list of active pysmurf-controller agents on a network from
        the registry agent. Uses this to populate the ``smurfs`` dictionary,
        which contains an OCSClient object for each.
        """
        reg_agents = self.reg.main.status().session['data']
        self.smurfs = {}
        for k, v in reg_agents.items():
            if 'pysmurf-controller' not in k:
                continue
            if v['expired']:
                continue

            instance_id = k.split('.')[-1]
            smurf_key = instance_id.split('-')[-1]
            self.smurfs[smurf_key] = OCSClient(instance_id,
                                               args=self.client_args)

    def start(self, op_name, ids=None, **kwargs):
        """
        Starts an operation on any or all pysmurf controllers.

        Args
        ----
        op_name : str
            Name of the operation to start
        ids : list, optional
            List of pysmurf-controller id's. This defaults to running on all
            controllers.
        **kwargs
            Any additional keyword arguments are passed onto the start
            operation as params
        """
        if ids is None:
            ids = list(self.smurfs.keys())
        elif isinstance(ids, str):
            ids = [ids]
        rv = {}
        for smurf_id in ids:
            rv[smurf_id] = getattr(self.smurfs[smurf_id], op_name).start(**kwargs)
        return rv

    def stop(self, op_name, ids=None, **kwargs):
        """
        Stops an operation on any or all pysmurf controllers.

        Args
        ----
        op_name : str
            Name of the operation to stop
        ids : list, optional
            List of pysmurf-controller id's. This defaults to running on all
            controllers.
        **kwargs
            Any additional keyword arguments are passed onto the stop operation
            as params
        """
        if ids is None:
            ids = list(self.smurfs.keys())
        elif isinstance(ids, str):
            ids = [ids]
        rv = {}
        for smurf_id in ids:
            rv[smurf_id] = getattr(self.smurfs[smurf_id], op_name).stop(**kwargs)
        return rv

    def status(self, op_name, ids=None):
        """
        Checks the status of an operation on any or all pysmurf controllers

        Args
        ----
        op_name : str
            Name of the operation to stop
        ids : list, optional
            List of pysmurf-controller id's. This defaults to running on all
            controllers.
        """
        if ids is None:
            ids = list(self.smurfs.keys())
        elif isinstance(ids, str):
            ids = [ids]
        rv = {}
        for smurf_id in ids:
            rv[smurf_id] = getattr(self.smurfs[smurf_id], op_name).status()
        return rv

    def wait(self, op_name, ids=None):
        """
        Waits for an operation to finish on any or all pysmurf controllers.
        This will block until the operation sessions of all speicified ID's
        have been completed.

        Args
        ----
        op_name : str
            Name of the operation to stop
        ids : list, optional
            List of pysmurf-controller id's. This defaults to running on all
            controllers.
        """
        if ids is None:
            ids = list(self.smurfs.keys())
        elif isinstance(ids, str):
            ids = [ids]
        rv = {}
        for smurf_id in ids:
            rv[smurf_id] = getattr(self.smurfs[smurf_id], op_name).wait()
        return rv



package_name = 'socs'
agents = {
    'ACUAgent': {'module': 'socs.agents.acu.agent', 'entry_point': 'main'},
    'BLHAgent': {'module': 'socs.agents.orientalmotor_blh.agent', 'entry_point': 'main'},
    'BlueforsAgent': {'module': 'socs.agents.bluefors.agent', 'entry_point': 'main'},
    'CrateAgent': {'module': 'socs.agents.smurf_crate_monitor.agent', 'entry_point': 'main'},
    'CryomechCPAAgent': {'module': 'socs.agents.cryomech_cpa.agent', 'entry_point': 'main'},
    'DS378Agent': {'module': 'socs.agents.devantech_dS378.agent', 'entry_point': 'main'},
    'FPGAAgent': {'module': 'socs.agents.holo_fpga.agent', 'entry_point': 'main'},
    'FlowmeterAgent': {'module': 'socs.agents.ifm_sbn246_flowmeter.agent', 'entry_point': 'main'},
    'FTSAerotechAgent': {'module': 'socs.agents.fts_aerotech.agent', 'entry_point': 'main'},
    'GalilAxisAgent': {'module': 'socs.agents.galil_axis.agent', 'entry_point': 'main'},
    'GeneratorAgent': {'module': 'socs.agents.generator.agent', 'entry_point': 'main'},
    'Hi6200Agent': {'module': 'socs.agents.hi6200.agent', 'entry_point': 'main'},
    'HTTPCameraAgent': {'module': 'socs.agents.http_camera.agent', 'entry_point': 'main'},
    'HWPBBBAgent': {'module': 'socs.agents.hwp_encoder.agent', 'entry_point': 'main'},
    'HWPGripperAgent': {'module': 'socs.agents.hwp_gripper.agent', 'entry_point': 'main'},
    'HWPPCUAgent': {'module': 'socs.agents.hwp_pcu.agent', 'entry_point': 'main'},
    'HWPPicoscopeAgent': {'module': 'socs.agents.hwp_picoscope.agent', 'entry_point': 'main'},
    'HWPPIDAgent': {'module': 'socs.agents.hwp_pid.agent', 'entry_point': 'main'},
    'HWPPMXAgent': {'module': 'socs.agents.hwp_pmx.agent', 'entry_point': 'main'},
    'HWPSupervisor': {'module': 'socs.agents.hwp_supervisor.agent', 'entry_point': 'main'},
    'ibootbarAgent': {'module': 'socs.agents.ibootbar.agent', 'entry_point': 'main'},
    'LabJackAgent': {'module': 'socs.agents.labjack.agent', 'entry_point': 'main'},
    'Lakeshore240Agent': {'module': 'socs.agents.lakeshore240.agent', 'entry_point': 'main'},
    'Lakeshore336Agent': {'module': 'socs.agents.lakeshore336.agent', 'entry_point': 'main'},
    'Lakeshore370Agent': {'module': 'socs.agents.lakeshore370.agent', 'entry_point': 'main'},
    'Lakeshore372Agent': {'module': 'socs.agents.lakeshore372.agent', 'entry_point': 'main'},
    'Lakeshore425Agent': {'module': 'socs.agents.lakeshore425.agent', 'entry_point': 'main'},
    'LATRtXYStageAgent': {'module': 'socs.agents.xy_stage.agent', 'entry_point': 'main'},
    'LDMonitorAgent': {'module': 'socs.agents.ld_monitor.agent', 'entry_point': 'main'},
    'MagpieAgent': {'module': 'socs.agents.magpie.agent', 'entry_point': 'main'},
    'MeinbergM1000Agent': {'module': 'socs.agents.meinberg_m1000.agent', 'entry_point': 'main'},
    'MeinbergSyncboxAgent': {'module': 'socs.agents.meinberg_syncbox.agent', 'entry_point': 'main'},
    'PCR500MAAgent': {'module': 'socs.agents.kikusui_pcr500ma.agent', 'entry_point': 'main'},
    'PfeifferAgent': {'module': 'socs.agents.pfeiffer_tpg366.agent', 'entry_point': 'main'},
    'PfeifferTC400Agent': {'module': 'socs.agents.pfeiffer_tc400.agent', 'entry_point': 'main'},
    'PysmurfController': {'module': 'socs.agents.pysmurf_controller.agent', 'entry_point': 'main'},
    'PysmurfMonitor': {'module': 'socs.agents.pysmurf_monitor.agent', 'entry_point': 'main'},
    'RTSPCameraAgent': {'module': 'socs.agents.rtsp_camera.agent', 'entry_point': 'main'},
    'ScpiPsuAgent': {'module': 'socs.agents.scpi_psu.agent', 'entry_point': 'main'},
    'SmurfFileEmulator': {'module': 'socs.agents.smurf_file_emulator.agent', 'entry_point': 'main'},
    'SmurfStreamSimulator': {'module': 'socs.agents.smurf_stream_simulator.agent', 'entry_point': 'main'},
    'SmurfTimingCardAgent': {'module': 'socs.agents.smurf_timing_card.agent', 'entry_point': 'main'},
    'SRSCG635Agent': {'module': 'socs.agents.srs_cg635.agent', 'entry_point': 'main'},
    'StimEncAgent': {'module': 'socs.agents.stimulator_encoder.agent', 'entry_point': 'main'},
    'StimThermometerAgent': {'module': 'socs.agents.stimulator_thermometer.agent', 'entry_point': 'main'},
    'SupRsync': {'module': 'socs.agents.suprsync.agent', 'entry_point': 'main'},
    'SynaccessAgent': {'module': 'socs.agents.synacc.agent', 'entry_point': 'main'},
    'SynthAgent': {'module': 'socs.agents.holo_synth.agent', 'entry_point': 'main'},
    'TektronixAWGAgent': {'module': 'socs.agents.tektronix3021c.agent', 'entry_point': 'main'},
    'ThorlabsMC2000BAgent': {'module': 'socs.agents.thorlabs_mc2000b.agent', 'entry_point': 'main'},
    'UCSCRadiometerAgent': {'module': 'socs.agents.ucsc_radiometer.agent', 'entry_point': 'main'},
    'UPSAgent': {'module': 'socs.agents.ups.agent', 'entry_point': 'main'},
    'VantagePro2Agent': {'module': 'socs.agents.vantagepro2.agent', 'entry_point': 'main'},
    'WiregridActuatorAgent': {'module': 'socs.agents.wiregrid_actuator.agent', 'entry_point': 'main'},
    'WiregridEncoderAgent': {'module': 'socs.agents.wiregrid_encoder.agent', 'entry_point': 'main'},
    'WiregridKikusuiAgent': {'module': 'socs.agents.wiregrid_kikusui.agent', 'entry_point': 'main'},
    'WiregridTiltSensorAgent': {'module': 'socs.agents.wiregrid_tiltsensor.agent', 'entry_point': 'main'},
}



import time

from socs.tcp import TCPInterface

WAIT_TIME = 0.01
BUFFSIZE = 128

protection_status_key = [
    'Over voltage',
    'Over current',
    'AC power failure or power interuption',
    '',
    'Over temperature',
    '',
    'IOC communication error',
    '',
]


class PMX(TCPInterface):
    """The PMX object for communicating with the Kikusui PMX power supplies.

    Args:
        ip_address (str): IP address of the device.
        port (int): Associated port for TCP communication.
        timeout (float): Duration in seconds that operations wait before giving
            up.

    """

    def __init__(self, ip_address, port=5025, timeout=10):
        # Setup the TCP Interface
        super().__init__(ip_address, port, timeout)

    def close(self):
        self.comm.close()

    def send_message(self, msg, read=True):
        if not msg[-1] == '\n':
            msg += '\n'
        self.send(msg.encode())
        time.sleep(0.5)
        if read:
            data = self.recv(BUFFSIZE).strip().decode('utf-8')
            return data

    def _wait(self):
        time.sleep(WAIT_TIME)

    def check_output(self):
        """ Return the output status """
        val = int(self.send_message('output?'))
        msg = "Measured output state = "
        states = {0: 'OFF', 1: 'ON'}
        if val in states:
            msg += states[val]
        else:
            msg += 'Fail'
        return msg, val

    def check_error(self):
        """ Check oldest error from error queues. Error queues store up to 255 errors """
        val = self.send_message(':system:error?')
        code, msg = val.split(',')
        code = int(code)
        msg = msg[1:-2]
        return msg, code

    def clear_alarm(self):
        """ Clear alarm """
        self.send_message('output:protection:clear', read=False)

    def turn_on(self):
        """ Turn the PMX on """
        self.send_message('output 1', read=False)
        self._wait()
        return self.check_output()

    def turn_off(self):
        """ Turn the PMX off """
        self.send_message('output 0', read=False)
        self._wait()
        return self.check_output()

    def check_current(self):
        """ Check the current setting """
        val = float(self.send_message('curr?'))
        msg = "Current setting = {:.3f} A".format(val)
        return msg, val

    def check_voltage(self):
        """ Check the voltage setting """
        val = float(self.send_message('volt?'))
        msg = "Voltage setting = {:.3f} V".format(val)
        return msg, val

    def meas_current(self):
        """ Measure the current """
        val = float(self.send_message('meas:curr?'))
        msg = "Measured current = {:.3f} A".format(val)
        return msg, val

    def meas_voltage(self):
        """ Measure the voltage """
        val = float(self.send_message('meas:volt?'))
        msg = "Measured voltage = {:.3f} V".format(val)
        return msg, val

    def set_current(self, curr):
        """ Set the current """
        self.send_message('curr %a' % curr, read=False)
        self._wait()
        return self.check_current()

    def set_voltage(self, vol):
        """ Set the voltage """
        self.send_message('volt %a' % vol, read=False)
        self._wait()
        return self.check_voltage()

    def check_source(self):
        """ Check the source of PMX """
        val = self.send_message('volt:ext:sour?')
        msg = "Source: " + val
        return msg, val

    def use_external_voltage(self):
        """ Set PMX to use external voltage """
        self.send_message('volt:ext:sour volt', read=False)
        self._wait()
        return self.check_source()

    def ign_external_voltage(self):
        """ Set PMX to ignore external voltage """
        self.send_message('volt:ext:sour none', read=False)
        self._wait()
        return self.check_source()

    def check_current_limit(self):
        """ Check the PMX current protection limit """
        val = float(self.send_message('curr:prot?'))
        msg = "Current protection limit = {:.3f} A".format(val)
        return msg, val

    def check_voltage_limit(self):
        """ Check the PMX voltage protection limit """
        val = float(self.send_message('volt:prot?'))
        msg = "Voltage protection limit = {:.3f} V".format(val)
        return msg, val

    def set_current_limit(self, curr_lim):
        """ Set the PMX current protection limit """
        self.send_message('curr:prot %a' % curr_lim, read=False)
        self._wait()
        return self.check_current_limit()

    def set_voltage_limit(self, vol_lim):
        """ Set the PMX voltage protection limit """
        self.send_message('volt:prot %a' % vol_lim, read=False)
        self._wait()
        return self.check_voltage_limit()

    def check_prot(self):
        """ Check the protection status
        Return:
            val (int): protection status code
        """
        val = int(self.send_message('stat:ques?'))
        return val

    def get_prot_msg(self, val):
        """ Get the protection status message
        Args:
            val (int): protection status code
        Return:
            msg (str): protection status message
        """
        msg = []
        for i in range(8):
            if (val >> i & 1):
                msg.append(protection_status_key[i])
        msg = ', '.join(msg)
        return msg
